| Title: | Time Series Forecasting using THETA-SVM Hybrid Model |
|---|---|
| Description: | Testing, Implementation, and Forecasting of the THETA-SVM hybrid model. The THETA-SVM hybrid model combines the distinct strengths of the THETA model and the Support Vector Machine (SVM) model for time series forecasting.For method details see Bhattacharyya et al. (2022) <doi:10.1007/s11071-021-07099-3>. |
| Authors: | Fasila K. P. [aut, ctb], Mrinmoy Ray [aut, cre], Rajeev Ranjan Kumar [aut, ctb], K. N. Singh [aut, ctb], Amrender Kumar [aut, ctb], Santosha Rathod [aut, ctb] |
| Maintainer: | Mrinmoy Ray <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-26 07:45:47 UTC |
| Source: | https://github.com/cran/THETASVM |
The THSVM function fit THETA-SVM hybrid model for time series data.
THSVM(data,h)THSVM(data,h)
data |
Input univariate time series (ts) data. |
h |
The forecast horizon. |
This package allows you to fit the THETA-SVM hybrid model.
Test_Result |
Checking the suitability of data for hybrid modelling |
THETA coefficients |
Coefficients of the fitted THETA |
SVM Summary |
Summary of the fitted SVM model on residuals obtained from the fitted THETA model |
Optimal Lag |
Optimal Lag of the fitted SVM model |
MAPE |
Mean Absolute Percentage Error (MAPE) of the fitted hybrid model |
MSE |
Mean Square Error (MSE) of fitted hybrid model |
fitted |
Fitted values of hybrid model |
forecasted.values |
h step ahead forecasted values employing hybrid model |
Fasila K. P., Mrinmoy Ray, Rajeev Ranjan Kumar, K. N. Singh, Amrender Kumar, Santosha Rathod
Bhattacharyya, A., Chakraborty, T., and Rai, S. N. (2022). Stochastic forecasting of COVID-19 daily new cases across countries with a novel hybrid time series model. Nonlinear Dynamics, 107(3), 3025–3040.
ARSVM, ARIMAANN
data=lynx THSVM(data,5)data=lynx THSVM(data,5)